@@ -88,11 +88,10 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
 #ifdef _OPENMP
         #pragma omp for
 #endif
-#if defined(linux) || defined(__APPLE__)
-        for (unsigned int n = 0; n < nVectorsPerRank; n++) {
-#endif
 #ifdef _WIN32
-		for (int n = 0; n < nVectorsPerRank; n++) {
+	for (int n = 0; n < nVectorsPerRank; n++) {
+#else
+        for (unsigned int n = 0; n < nVectorsPerRank; n++) {
 #endif
             if (itask*nVectorsPerRank+n<nVectors) {
                 /// get the best matching unit
@@ -112,11 +111,10 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
 #ifdef _OPENMP
         #pragma omp for
 #endif
-#if defined(linux) || defined(__APPLE__)
-		for (unsigned int som_y = 0; som_y < nSomY; som_y++) {
-#endif
 #ifdef _WIN32
 		for (int som_y = 0; som_y < nSomY; som_y++) {
+#else
+                for (unsigned int som_y = 0; som_y < nSomY; som_y++) {
 #endif
             for (unsigned int som_x = 0; som_x < nSomX; som_x++) {
                 localDenominator[som_y*nSomX + som_x] = 0.0;
@@ -128,11 +126,10 @@ void trainOneEpochDenseCPU(int itask, float *data, float *numerator,
 #ifdef _OPENMP
         #pragma omp for
 #endif
-#if defined(linux) || defined(__APPLE__)
-        for (unsigned int som_y = 0; som_y < nSomY; som_y++) {
-#endif
 #ifdef _WIN32
-		for (int som_y = 0; som_y < nSomY; som_y++) {
+	for (int som_y = 0; som_y < nSomY; som_y++) {
+#else
+        for (unsigned int som_y = 0; som_y < nSomY; som_y++) {
 #endif
             for (unsigned int som_x = 0; som_x < nSomX; som_x++) {
                 for (unsigned int n = 0; n < nVectorsPerRank; n++) {
